==> xrmap-2.29.tar.bz2: xrmap-2.29/menudefs.h <==
/* List of messages */

#include "numdefs.h"

/* Menu definitions */

#define NUM_DATAFILE END_DATAFILE_DESCRIPTION-BEGIN_DATAFILE_DESCRIPTION
#define NUM_EXTERNAL END_EXTERNAL_DESCRIPTION-BEGIN_EXTERNAL_DESCRIPTION
#define NUM_PRINTCFG END_PRINTCFG_DESCRIPTION-BEGIN_PRINTCFG_DESCRIPTION
#define NUM_SAVE END_SAVE_DESCRIPTION-BEGIN_SAVE_DESCRIPTION
#define NUM_PARAM END_PARAMETER_DESCRIPTION-BEGIN_PARAMETER_DESCRIPTION
#define NUM_DISPLAY END_DISPLAY_DESCRIPTION-BEGIN_DISPLAY_DESCRIPTION
#define NUM_FONTS END_FONT_DESCRIPTION-BEGIN_FONT_DESCRIPTION
#define NUM_MARKS END_MARKS_DESCRIPTION-BEGIN_MARKS_DESCRIPTION
#define NUM_CONTIN END_CONTINENT_DESCRIPTION-BEGIN_CONTINENT_DESCRIPTION
#define NUM_CAT END_CATEGORY_DESCRIPTION-BEGIN_CATEGORY_DESCRIPTION

enum {OUT_NONE=0, OUT_PPM, OUT_XPM, OUT_EPS, OUT_PS, OUT_RC, OUT_DUMP };
enum {MODE_RUN=0, MODE_CMD, MODE_FILE, 
      MODE_MENU, MODE_OPTION, MODE_COLOR, MODE_HELP };

enum {M_RUN_START=0 };
enum {M_CMD_START=0 };
enum {M_FILE_START=0, M_FILE_DATA, M_FILE_EXTERNAL, 
      M_FILE_PRINTCFG, M_FILE_SAVE };
enum {M_MENU_LIST=-1, M_MENU_START=0, M_MENU_FILE, M_MENU_CMD, M_MENU_SEARCH, 
      M_MENU_OPTION, M_MENU_COLOR, M_MENU_HELP };
enum {M_OPTION_START=0, M_OPTION_PARAM, M_OPTION_DISPLAY, M_OPTION_FONT, 
      M_OPTION_MARKS, M_OPTION_CONTIN, M_OPTION_CAT };
enum {M_COLOR_START=0, M_COLOR_WIDGETS, M_COLOR_LABELS,
      M_COLOR_INTERN, M_COLOR_NATION, M_COLOR_RIVERS, M_COLOR_CIL };
enum {M_HELP_START=0, M_HELP_SHORTCUTS, M_HELP_ABOUT, M_HELP_DOC, 
      M_HELP_EXTRA, M_HELP_EDIT};

static char *labels_generalmenu = NULL;
static char *labels_filemenu = NULL;
static char *labels_optionmenu = NULL;
static char *labels_colormenu = NULL;
static char *labels_helpmenu = NULL;

static char ** projtype = NULL;
static char ** itemtype = NULL;

static char ** wintitle_descr = NULL;
static char ** datafile_descr = NULL;
static char ** external_descr = NULL;
static char ** printcfg_descr = NULL;
static char ** save_descr = NULL;
static char ** searchby_descr = NULL;
static char ** parameter_descr = NULL;
static char ** display_descr = NULL;
static char ** font_descr = NULL;
static char ** marks_descr = NULL;
static char ** continent_descr = NULL;
static char ** category_descr = NULL;
static char ** doc_descr = NULL;

#define NUM_ITEMS 5
static char * item_name[NUM_ITEMS] = 
      { "cfg", "international", "national", "rivers", "cil" };

#define NUM_CONTINENTS 6
static char * continent_name[NUM_CONTINENTS] = 
      { "Africa", "Asia", "Europe", "NAmerica", "SAmerica", "Oceanic" };

==> xrmap-2.33.tar.bz2: xrmap-2.33/menudefs.h <==
/* List of messages */

#include "numdefs.h"

/* Menu definitions */

#define NUM_DATAFILE END_DATAFILE_DESCRIPTION-BEGIN_DATAFILE_DESCRIPTION
#define NUM_EXTERNAL END_EXTERNAL_DESCRIPTION-BEGIN_EXTERNAL_DESCRIPTION
#define NUM_PRINTCFG END_PRINTCFG_DESCRIPTION-BEGIN_PRINTCFG_DESCRIPTION
#define NUM_SAVE END_SAVE_DESCRIPTION-BEGIN_SAVE_DESCRIPTION
#define NUM_PARAM END_PARAMETER_DESCRIPTION-BEGIN_PARAMETER_DESCRIPTION
#define NUM_HIERARCHY END_HIERARCHY_DESCRIPTION-BEGIN_HIERARCHY_DESCRIPTION
#define NUM_FONTS END_FONT_DESCRIPTION-BEGIN_FONT_DESCRIPTION
#define NUM_MARKS END_MARKS_DESCRIPTION-BEGIN_MARKS_DESCRIPTION
#define NUM_CONTIN END_CONTINENT_DESCRIPTION-BEGIN_CONTINENT_DESCRIPTION
#define NUM_CAT END_CATEGORY_DESCRIPTION-BEGIN_CATEGORY_DESCRIPTION

enum {OUT_NONE=0, OUT_PPM, OUT_XPM, OUT_EPS, OUT_PS, OUT_RC, OUT_DUMP };
enum {MODE_RUN=0, MODE_CMD, MODE_FILE, 
      MODE_MENU, MODE_OPTION, MODE_COLOR, MODE_HELP };

enum {M_RUN_START=0 };
enum {M_CMD_START=0 };
enum {M_FILE_START=0, M_FILE_DATA, M_FILE_EXTERNAL, 
      M_FILE_PRINTCFG, M_FILE_SAVE };
enum {M_MENU_LIST=-1, M_MENU_START=0, M_MENU_FILE, M_MENU_CMD, M_MENU_SEARCH, 
      M_MENU_OPTION, M_MENU_COLOR, M_MENU_HELP };
enum {M_OPTION_START=0, M_OPTION_PARAM, M_OPTION_HIERARCHY, M_OPTION_FONT, 
      M_OPTION_MARKS, M_OPTION_CONTIN, M_OPTION_CAT };
enum {M_COLOR_START=0, M_COLOR_WIDGETS, M_COLOR_LABELS,
      M_COLOR_INTERN, M_COLOR_NATION, M_COLOR_RIVERS, M_COLOR_CIL };
enum {M_HELP_START=0, M_HELP_SHORTCUTS, M_HELP_ABOUT, M_HELP_DOC, 
      M_HELP_EXTRA, M_HELP_EDIT};

static char *labels_generalmenu = NULL;
static char *labels_filemenu = NULL;
static char *labels_optionmenu = NULL;
static char *labels_colormenu = NULL;
static char *labels_helpmenu = NULL;

static char ** projtype = NULL;
static char ** itemtype = NULL;

static char ** wintitle_descr = NULL;
static char ** datafile_descr = NULL;
static char ** external_descr = NULL;
static char ** printcfg_descr = NULL;
static char ** save_descr = NULL;
static char ** searchby_descr = NULL;
static char ** parameter_descr = NULL;
static char ** display_descr = NULL;
static char ** font_descr = NULL;
static char ** marks_descr = NULL;
static char ** continent_descr = NULL;
static char ** category_descr = NULL;
static char ** doc_descr = NULL;

#define NUM_ITEMS 5
static char * item_name[NUM_ITEMS] = 
      { "cfg", "international", "national", "rivers", "cil" };

#define NUM_CONTINENTS 6
static char * continent_name[NUM_CONTINENTS] = 
      { "Africa", "Asia", "Europe", "NAmerica", "SAmerica", "Oceanic" };
